pub struct ClientSmeGetApfPacketFilterEnabledResponse {
pub enabled: bool,
}Fields
enabled: boolTrait Implementations
Sourceimpl Clone for ClientSmeGetApfPacketFilterEnabledResponse
impl Clone for ClientSmeGetApfPacketFilterEnabledResponse
Sourcefn clone(&self) -> ClientSmeGetApfPacketFilterEnabledResponse
fn clone(&self) -> ClientSmeGetApfPacketFilterEnabledResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<ClientSmeGetApfPacketFilterEnabledResponse, D> for ClientSmeGetApfPacketFilterEnabledResponsewhere
D: ResourceDialect,
impl<D> Decode<ClientSmeGetApfPacketFilterEnabledResponse, D> for ClientSmeGetApfPacketFilterEnabledResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> ClientSmeGetApfPacketFilterEnabledResponse
fn new_empty() -> ClientSmeGetApfPacketFilterEnabledResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<ClientSmeGetApfPacketFilterEnabledResponse, D> for &ClientSmeGetApfPacketFilterEnabledResponsewhere
D: ResourceDialect,
impl<D> Encode<ClientSmeGetApfPacketFilterEnabledResponse, D> for &ClientSmeGetApfPacketFilterEnabledResponsewhere
D: ResourceDialect,
Sourceimpl Ord for ClientSmeGetApfPacketFilterEnabledResponse
impl Ord for ClientSmeGetApfPacketFilterEnabledResponse
Sourcefn cmp(&self, other: &ClientSmeGetApfPacketFilterEnabledResponse) -> Ordering
fn cmp(&self, other: &ClientSmeGetApfPacketFilterEnabledResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClientSmeGetApfPacketFilterEnabledResponse
impl PartialEq for ClientSmeGetApfPacketFilterEnabledResponse
Sourcefn eq(&self, other: &ClientSmeGetApfPacketFilterEnabledResponse) -> bool
fn eq(&self, other: &ClientSmeGetApfPacketFilterEnabledResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClientSmeGetApfPacketFilterEnabledResponse
impl PartialOrd for ClientSmeGetApfPacketFilterEnabledResponse
Sourceimpl TypeMarker for ClientSmeGetApfPacketFilterEnabledResponse
impl TypeMarker for ClientSmeGetApfPacketFilterEnabledResponse
Sourcetype Owned = ClientSmeGetApfPacketFilterEnabledResponse
type Owned = ClientSmeGetApfPacketFilterEnabledResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ClientSmeGetApfPacketFilterEnabledResponse
impl ValueTypeMarker for ClientSmeGetApfPacketFilterEnabledResponse
Sourcetype Borrowed<'a> = &'a ClientSmeGetApfPacketFilterEnabledResponse
type Borrowed<'a> = &'a ClientSmeGetApfPacketFilterEnabledResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<ClientSmeGetApfPacketFilterEnabledResponse as TypeMarker>::Owned,
) -> <ClientSmeGetApfPacketFilterEnabledResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<ClientSmeGetApfPacketFilterEnabledResponse as TypeMarker>::Owned, ) -> <ClientSmeGetApfPacketFilterEnabledResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Copy for ClientSmeGetApfPacketFilterEnabledResponse
impl Eq for ClientSmeGetApfPacketFilterEnabledResponse
impl Persistable for ClientSmeGetApfPacketFilterEnabledResponse
impl StructuralPartialEq for ClientSmeGetApfPacketFilterEnabledResponse