pub struct ClientSmeInstallApfPacketFilterRequest {
pub program: Vec<u8>,
}Fields
program: Vec<u8>Trait Implementations
Sourceimpl Clone for ClientSmeInstallApfPacketFilterRequest
impl Clone for ClientSmeInstallApfPacketFilterRequest
Sourcefn clone(&self) -> ClientSmeInstallApfPacketFilterRequest
fn clone(&self) -> ClientSmeInstallApfPacketFilterRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<ClientSmeInstallApfPacketFilterRequest, D> for ClientSmeInstallApfPacketFilterRequestwhere
D: ResourceDialect,
impl<D> Decode<ClientSmeInstallApfPacketFilterRequest, D> for ClientSmeInstallApfPacketFilterRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> ClientSmeInstallApfPacketFilterRequest
fn new_empty() -> ClientSmeInstallApfPacketFilterRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl<D> Encode<ClientSmeInstallApfPacketFilterRequest, D> for &ClientSmeInstallApfPacketFilterRequestwhere
D: ResourceDialect,
impl<D> Encode<ClientSmeInstallApfPacketFilterRequest, D> for &ClientSmeInstallApfPacketFilterRequestwhere
D: ResourceDialect,
Sourceimpl Ord for ClientSmeInstallApfPacketFilterRequest
impl Ord for ClientSmeInstallApfPacketFilterRequest
Sourcefn cmp(&self, other: &ClientSmeInstallApfPacketFilterRequest) -> Ordering
fn cmp(&self, other: &ClientSmeInstallApfPacketFilterRequest) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClientSmeInstallApfPacketFilterRequest
impl PartialEq for ClientSmeInstallApfPacketFilterRequest
Sourcefn eq(&self, other: &ClientSmeInstallApfPacketFilterRequest) -> bool
fn eq(&self, other: &ClientSmeInstallApfPacketFilterRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClientSmeInstallApfPacketFilterRequest
impl PartialOrd for ClientSmeInstallApfPacketFilterRequest
Sourceimpl TypeMarker for ClientSmeInstallApfPacketFilterRequest
impl TypeMarker for ClientSmeInstallApfPacketFilterRequest
Sourcetype Owned = ClientSmeInstallApfPacketFilterRequest
type Owned = ClientSmeInstallApfPacketFilterRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ClientSmeInstallApfPacketFilterRequest
impl ValueTypeMarker for ClientSmeInstallApfPacketFilterRequest
Sourcetype Borrowed<'a> = &'a ClientSmeInstallApfPacketFilterRequest
type Borrowed<'a> = &'a ClientSmeInstallApfPacketFilterRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<ClientSmeInstallApfPacketFilterRequest as TypeMarker>::Owned,
) -> <ClientSmeInstallApfPacketFilterRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<ClientSmeInstallApfPacketFilterRequest as TypeMarker>::Owned, ) -> <ClientSmeInstallApfPacketFilterRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Eq for ClientSmeInstallApfPacketFilterRequest
impl Persistable for ClientSmeInstallApfPacketFilterRequest
impl StructuralPartialEq for ClientSmeInstallApfPacketFilterRequest