pub struct ClientSmeStartScheduledScanRequest {
pub req: ScheduledScanRequest,
pub txn: ServerEnd<ScheduledScanTransactionMarker>,
}Fields
req: ScheduledScanRequesttxn: ServerEnd<ScheduledScanTransactionMarker>Trait Implementations
Sourceimpl Decode<ClientSmeStartScheduledScanRequest, DefaultFuchsiaResourceDialect> for ClientSmeStartScheduledScanRequest
impl Decode<ClientSmeStartScheduledScanRequest, DefaultFuchsiaResourceDialect> for ClientSmeStartScheduledScanRequest
Sourceimpl Encode<ClientSmeStartScheduledScanRequest, DefaultFuchsiaResourceDialect> for &mut ClientSmeStartScheduledScanRequest
impl Encode<ClientSmeStartScheduledScanRequest, DefaultFuchsiaResourceDialect> for &mut ClientSmeStartScheduledScanRequest
Sourceimpl<T0: Encode<ScheduledScanRequest, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ServerEnd<ScheduledScanTransactionMarker>>, DefaultFuchsiaResourceDialect>> Encode<ClientSmeStartScheduledScanRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
impl<T0: Encode<ScheduledScanRequest, DefaultFuchsiaResourceDialect>, T1: Encode<Endpoint<ServerEnd<ScheduledScanTransactionMarker>>, DefaultFuchsiaResourceDialect>> Encode<ClientSmeStartScheduledScanRequest, DefaultFuchsiaResourceDialect> for (T0, T1)
Sourceimpl PartialEq for ClientSmeStartScheduledScanRequest
impl PartialEq for ClientSmeStartScheduledScanRequest
Sourcefn eq(&self, other: &ClientSmeStartScheduledScanRequest) -> bool
fn eq(&self, other: &ClientSmeStartScheduledScanRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ResourceTypeMarker for ClientSmeStartScheduledScanRequest
impl ResourceTypeMarker for ClientSmeStartScheduledScanRequest
Sourcetype Borrowed<'a> = &'a mut ClientSmeStartScheduledScanRequest
type Borrowed<'a> = &'a mut ClientSmeStartScheduledScanRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for ClientSmeStartScheduledScanRequest
impl TypeMarker for ClientSmeStartScheduledScanRequest
Sourcetype Owned = ClientSmeStartScheduledScanRequest
type Owned = ClientSmeStartScheduledScanRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Standalone<DefaultFuchsiaResourceDialect> for ClientSmeStartScheduledScanRequest
impl StructuralPartialEq for ClientSmeStartScheduledScanRequest