pub struct ScheduledScanTransactionMarker;Trait Implementations
Sourceimpl Clone for ScheduledScanTransactionMarker
impl Clone for ScheduledScanTransactionMarker
Sourcefn clone(&self) -> ScheduledScanTransactionMarker
fn clone(&self) -> ScheduledScanTransactionMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Ord for ScheduledScanTransactionMarker
impl Ord for ScheduledScanTransactionMarker
Sourcefn cmp(&self, other: &ScheduledScanTransactionMarker) -> Ordering
fn cmp(&self, other: &ScheduledScanTransactionMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ScheduledScanTransactionMarker
impl PartialEq for ScheduledScanTransactionMarker
Sourcefn eq(&self, other: &ScheduledScanTransactionMarker) -> bool
fn eq(&self, other: &ScheduledScanTransactionMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ScheduledScanTransactionMarker
impl PartialOrd for ScheduledScanTransactionMarker
Sourceimpl ProtocolMarker for ScheduledScanTransactionMarker
impl ProtocolMarker for ScheduledScanTransactionMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) ScheduledScanTransaction"
const DEBUG_NAME: &'static str = "(anonymous) ScheduledScanTransaction"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = ScheduledScanTransactionProxy
type Proxy = ScheduledScanTransactionProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = ScheduledScanTransactionRequestStream
type RequestStream = ScheduledScanTransactionRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = ScheduledScanTransactionSynchronousProxy
type SynchronousProxy = ScheduledScanTransactionSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for ScheduledScanTransactionMarker
impl Eq for ScheduledScanTransactionMarker
impl StructuralPartialEq for ScheduledScanTransactionMarker